# coding: utf8
# Part of the bioread package for reading BIOPAC data.
#
# Copyright (c) 2016 Board of Regents of the University of Wisconsin System
#
# Written Nate Vack <njvack@wisc.edu> with research from John Ollinger
# at the Waisman Laboratory for Brain Imaging and Behavior, University of
# Wisconsin-Madison
# Project home: http://github.com/njvack/bioread

from __future__ import absolute_import

from bioread import version as ver

version = ver.version_str()
author = "Nate Vack"
author_email = "njvack@freshforever.net"
license = "GPL 2.0"
copyright = "Copyright 2016 Boards of Regent of the University of Wisconsin System"  # noqa
url = "https://github.com/njvack/bioread"



# coding: utf8
# Part of the bioread package for reading BIOPAC data.
#
# Copyright (c) 2016 Board of Regents of the University of Wisconsin System
#
# Written Nate Vack <njvack@wisc.edu> with research from John Ollinger
# at the Waisman Laboratory for Brain Imaging and Behavior, University of
# Wisconsin-Madison
# Project home: http://github.com/njvack/bioread

VERSION = (1, 0, 4)


def version_str():
    return ".".join([str(p) for p in VERSION])


description = "bioread {0}".format(version_str())



#!/usr/bin/env python
# coding: utf8
# Part of the bioread package for reading BIOPAC data.
#
# Copyright (c) 2016 Board of Regents of the University of Wisconsin System
#
# Written Nate Vack <njvack@wisc.edu> with research from John Ollinger
# at the Waisman Laboratory for Brain Imaging and Behavior, University of
# Wisconsin-Madison
# Project home: http://github.com/njvack/bioread
#
# This script pulls all the markers from an AcqKnowledge file and writes it
# to a delimited format.

"""Print the event markers from an AcqKnowledge file.

Usage:
  acq_markers [options] <file>...
  acq_markers -h | --help
  acq_markers --version

Options:
  -o <file>     Write to a file instead of standard output.
"""

from __future__ import (
    unicode_literals, absolute_import, division, with_statement)

import sys
import csv

from bioread.vendor.docopt import docopt
from bioread import reader
from bioread import version


FIELDS = [
    'filename',
    'time (s)',
    'label',
    'channel',
    'type_code',
    'type'
]


def u8fx():
    if isinstance('x', str):
        return lambda s: s
    else:
        return lambda s: s.encode('utf-8')

uf = u8fx()

def marker_formatter(acq_filename, graph_sample_msec):
    """ Return a function that turns a marker into a dict. """
    def f(marker):
        return {
            'filename': uf(acq_filename),
            'time (s)': (marker.sample_index * graph_sample_msec) / 1000,
            'label': uf(marker.text),
            'channel': uf(marker.channel_name or 'Global'),
            'type_code': uf(marker.type_code or 'None'),
            'type': uf(marker.type)
        }
    return f


def acq_markers_output_file(input_filenames, output_filename):
    with open(output_filename, 'w') as f:
        return acq_markers(input_filenames, f)


def acq_markers(input_filenames, output_stream):
    csv_out = csv.DictWriter(output_stream, FIELDS, delimiter=str("\t"))
    csv_out.writeheader()
    for fname in input_filenames:
        with open(fname, 'rb') as infile:
            r = reader.Reader.read_headers(infile)
            mf = marker_formatter(fname, r.graph_header.sample_time)
            for m in r.datafile.event_markers:
                csv_out.writerow(mf(m))


def main(args=None):
    if args is None:
        args = sys.argv[1:]
    pargs = docopt(
        __doc__,
        args,
        version=version.description)

    if pargs['-o']:
        return acq_markers_output_file(pargs['<file>'], pargs['-o'])
    else:
        return acq_markers(pargs['<file>'], sys.stdout)


if __name__ == '__main__':
    sys.exit(main(sys.argv[1:]))



#!/usr/bin/env python
# coding: utf8

from setuptools import setup, find_packages
import os


def get_locals(filename):
    l = {}
    exec(open(filename, 'r').read(), {}, l)
    return l

metadata = get_locals(os.path.join('bioread', '_metadata.py'))

setup(
    name="bioread",
    version=metadata['version'],
    packages=find_packages(),
    install_requires=["numpy"],
    entry_points={
        'console_scripts': [
            'acq2mat = bioread.runners.acq2mat:main',
            'acq2txt = bioread.runners.acq2txt:main',
            'acq_info = bioread.runners.acq_info:main',
            'acq_markers = bioread.runners.acq_markers:main',
            'acq2hdf5 = bioread.runners.acq2hdf5:main'
        ]
    },

    # metadata for upload to PyPI
    author=metadata['author'],
    author_email=metadata['author_email'],
    description=("Utilities to read BIOPAC AcqKnowledge files"),
    license="GPL 2.0",
    keywords="science research physiological biopac convert library",
    url="http://github.com/njvack/bioread",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Scientific/Engineering :: Information Analysis"
    ],
)
